@@ -409,6 +409,7 @@ function Startup()
             getService(Ci.nsIObserverService);
   obs.addObserver(gDownloadObserver, "download-manager-remove-download", false);
   obs.addObserver(gDownloadObserver, "private-browsing", false);
+  obs.addObserver(gDownloadObserver, "browser-lastwindow-close-granted", false);
 
   // Clear the search box and move focus to the list on escape from the box
   gSearchBox.addEventListener("keypress", function(e) {
@@ -428,6 +429,7 @@ function Shutdown()
             getService(Ci.nsIObserverService);
   obs.removeObserver(gDownloadObserver, "private-browsing");
   obs.removeObserver(gDownloadObserver, "download-manager-remove-download");
+  obs.removeObserver(gDownloadObserver, "browser-lastwindow-close-granted");
 
   clearTimeout(gBuilder);
   gStmt.reset();
@@ -471,6 +473,13 @@ let gDownloadObserver = {
           }, 0);
         }
         break;
+      case "browser-lastwindow-close-granted":
+//@line 530 "/builds/slave/linux_build/build/toolkit/mozapps/downloads/content/downloads.js"
+        if (gDownloadManager.activeDownloadCount == 0) {
+          setTimeout(gCloseDownloadManager, 0);
+        }
+//@line 534 "/builds/slave/linux_build/build/toolkit/mozapps/downloads/content/downloads.js"
+        break;
     }
   }
 };
